==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/ToolActionPerformedEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
export let ToolActionPerformedEventArgsDescription = /*@__PURE__*/ (() => {
    class ToolActionPerformedEventArgsDescription extends Description {
        constructor() {
            super();
            this.j = false;
            this.h = null;
            this.f = null;
        }
        get_type() {
            return "ToolActionPerformedEventArgs";
        }
        get type() {
            return this.get_type();
        }
        get isAggregate() {
            return this.j;
        }
        set isAggregate(a) {
            this.j = a;
            this.e("IsAggregate");
        }
        get detail() {
            return this.h;
        }
        set detail(a) {
            this.h = a;
            this.e("Detail");
        }
        get detailCollection() {
            return this.f;
        }
        set detailCollection(a) {
            this.f = a;
            this.e("DetailCollection");
        }
    }
    ToolActionPerformedEventArgsDescription.$t = /*@__PURE__*/ markType(ToolActionPerformedEventArgsDescription, 'ToolActionPerformedEventArgsDescription', Description.$);
    return ToolActionPerformedEventArgsDescription;
})();

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm2015/lib/ToolActionPerformedEventArgsDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Description } from "./Description";
import { markType } from "./type";
/**
 * @hidden
 */
export let ToolActionPerformedEventArgsDescription = /*@__PURE__*/ (() => {
    class ToolActionPerformedEventArgsDescription extends Description {
        get_type() {
            return "ToolActionPerformedEventArgs";
        }
        get type() {
            return this.get_type();
        }
        constructor() {
            super();
            this.l = false;
            this.j = null;
            this.h = null;
        }
        get isAggregate() {
            return this.l;
        }
        set isAggregate(a) {
            this.l = a;
            this.g("IsAggregate");
        }
        get detail() {
            return this.j;
        }
        set detail(a) {
            this.j = a;
            this.g("Detail");
        }
        get detailCollection() {
            return this.h;
        }
        set detailCollection(a) {
            this.h = a;
            this.g("DetailCollection");
        }
    }
    ToolActionPerformedEventArgsDescription.$t = /*@__PURE__*/ markType(ToolActionPerformedEventArgsDescription, 'ToolActionPerformedEventArgsDescription', Description.$);
    return ToolActionPerformedEventArgsDescription;
})();
